#
# spec file for package ghc-transformers-compat
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name transformers-compat
Name:           ghc-%{pkg_name}
Version:        0.6.2
Release:        3.2
Summary:        A small compatibility shim for the transformers library
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel

%description
This package includes backported versions of types that were added to
transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
transformers 0.2 or 0.3 compatibility to run on old versions of the platform,
but also need those types.

Those users should be able to just depend on 'transformers >= 0.2' and
'transformers-compat >= 0.3'.

Note: missing methods are not supplied, but this at least permits the types to
be used.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update transformers-compat to version 0.6.2.
  * `transformers-compat` now uses automatic flags instead of manual ones.
    This has a number of benefits:
  * There is no need for making several simultaneous releases to support each
    flag combination.
  * As a result, the `cabal-install` constraint solver should have a much
    easier time figuring out install-plans involving `transformers-compat`.
    Due to old `cabal-install` bugs, `cabal-install-1.16` and older may have a
    harder time installing this package, so it is recommended that you use
    `cabal-install-1.18` or later. (Or, if you must use `cabal-install-1.16` or
    older, installing `transformers-compat` with the appropriate flags should
    help.)
  * Fix an oversight in which the `Control.Monad.Trans.Accum` and
    `Control.Monad.Trans.Select` modules were not backported when built with the
    `-ffour` flag.
  * Introduce the `Data.Functor.Classes.Generic` module, which provides functions that can generically implement methods in the `Eq1`, `Ord1`, `Read1`, and `Show1` classes (without the usual boilerplate involved).
  * Introduce the `generic-deriving` flag. When enabled, `transformers-compat` will depend on the `generic-deriving` library on older versions of GHC to backport `GHC.Generics` support for `Generic` instances and the machinery in `Data.Functor.Classes.Generic`.
  * Some instances were present in `Data.Functor.Sum` but not in `Control.Monad.Trans.Instances` (e.g., the `Generic`, `Typeable`, and `Data` instances for `Sum`). This has been fixed.
  * Backport changes from `transformers-0.5.5`:
  * Backport the `Semigroup` instance for `Constant`
  * Add `mapSelect` and `mapSelectT`
  * Define `selectToContT` (and deprecate `selectToCont` in favor of that)
  * Define some explicit `(*>)` definitions to avoid space leaks
  * Backport changes from `transformers-0.5.4` (i.e., add `Bifoldable` and `Bitraversable` instances for `Data.Functor.Constant`)
  * Backport changes from `transformers-0.5.3`:
  * Backport the `Control.Monad.Trans.Accum` and `Control.Monad.Trans.Select` modules
  * Backport the `eitherToErrors` and `elimLift` functions to `Control.Applicative.Lift`
  * Backport `Bits`, `FiniteBits`, `IsString`, `Num`, `Real`, `Integral`, `Fractional`, `Floating`, `RealFrac`, and `RealFloat` instances for `Data.Functor.Identity`
  * Backport `Monad`, `MonadFail`, and `MonadPlus` instances for `Data.Functor.Reverse`
  * Backport `Eq1`, `Ord1`, `Read1`, and `Show1` instances for `Data.Proxy`
  * Backport changes from `transformers-0.5.2` (i.e., add more `INLINE` annotations)
  * Backport changes from `transformers-0.5.1` (i.e., add `Bounded`, `Enum`, `Ix`, and `Storable` instances for `Identity`)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.5.1.4 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.0.4 revision 0 with cabal2obs.
* Wed May 13 2015 mimi.vx@gmail.com
- update to 0.4.0.4
* Tue Apr 21 2015 mimi.vx@gmail.com
- initial commit
